sqlobject.tests.test_cache module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_cache module

class `sqlobject.tests.test_cache.` `CacheTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byName`(val, connection=None)
  `j` = cache_test
  property `name`
  `q` = cache_test
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_cache.CacheTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'cache_test'

class `sqlobject.tests.test_cache.` `Something`

  Bases: `object`

`sqlobject.tests.test_cache.` `test_cache`()

`sqlobject.tests.test_cache.` `test_cache_cull`()

`sqlobject.tests.test_cache.` `test_purge1`()